@@ -31,72 +31,72 @@ class KActionCollection;
 
 namespace kt
 {
-    class GUI;
-    class Core;
-    class View;
-    class Group;
-    class GroupView;
-    class GroupManager;
-    class View;
+class GUI;
+class Core;
+class View;
+class Group;
+class GroupView;
+class GroupManager;
+class View;
 
 
-    /**
-        @author Joris Guisson <joris.guisson@gmail.com>
-    */
-    class GroupView : public QTreeView
-    {
-        Q_OBJECT
-    public:
-        GroupView(GroupManager* gman, View* view, Core* core, GUI* gui, QWidget* parent);
-        ~GroupView() override;
+/**
+    @author Joris Guisson <joris.guisson@gmail.com>
+*/
+class GroupView : public QTreeView
+{
+    Q_OBJECT
+public:
+    GroupView(GroupManager* gman, View* view, Core* core, GUI* gui, QWidget* parent);
+    ~GroupView() override;
 
-        /// Save the status of the group view
-        void saveState(KSharedConfigPtr cfg);
+    /// Save the status of the group view
+    void saveState(KSharedConfigPtr cfg);
 
-        /// Load status from config
-        void loadState(KSharedConfigPtr cfg);
+    /// Load status from config
+    void loadState(KSharedConfigPtr cfg);
 
-        /// Create a new group
-        Group* addNewGroup();
+    /// Create a new group
+    Group* addNewGroup();
 
-        /// Setup all the actions of the GroupView
-        void setupActions(KActionCollection* col);
+    /// Setup all the actions of the GroupView
+    void setupActions(KActionCollection* col);
 
-    public slots:
-        /// Update the group count
-        void updateGroupCount();
+public Q_SLOTS:
+    /// Update the group count
+    void updateGroupCount();
 
-    private slots:
-        void onItemClicked(const QModelIndex& index);
-        void showContextMenu(const QPoint& p);
-        void addGroup();
-        void removeGroup();
-        void editGroupName();
-        void editGroupPolicy();
-        void openInNewTab();
+private Q_SLOTS:
+    void onItemClicked(const QModelIndex& index);
+    void showContextMenu(const QPoint& p);
+    void addGroup();
+    void removeGroup();
+    void editGroupName();
+    void editGroupPolicy();
+    void openInNewTab();
 
-    signals:
-        void currentGroupChanged(kt::Group* g);
-        void openTab(Group* g);
+Q_SIGNALS:
+    void currentGroupChanged(kt::Group* g);
+    void openTab(Group* g);
 
-    private:
-        void keyPressEvent(QKeyEvent* event) override;
+private:
+    void keyPressEvent(QKeyEvent* event) override;
 
-    private:
-        GUI* gui;
-        Core* core;
-        View* view;
-        GroupManager* gman;
-        GroupViewModel* model;
+private:
+    GUI* gui;
+    Core* core;
+    View* view;
+    GroupManager* gman;
+    GroupViewModel* model;
 
-        QAction * open_in_new_tab;
-        QAction * new_group;
-        QAction * edit_group;
-        QAction * remove_group;
-        QAction * edit_group_policy;
+    QAction * open_in_new_tab;
+    QAction * new_group;
+    QAction * edit_group;
+    QAction * remove_group;
+    QAction * edit_group_policy;
 
-        friend class GroupViewItem;
-    };
+    friend class GroupViewItem;
+};
 
 }
 
