@@ -29,37 +29,37 @@
 
 namespace bt
 {
-    class TorrentInterface;
+class TorrentInterface;
 }
 
 
 namespace kt
 {
 
-    /**
-        Extender widget which displays the results of a data scan
-    */
-    class ScanExtender : public JobProgressWidget, public Ui_ScanExtender
-    {
-        Q_OBJECT
-    public:
-        ScanExtender(bt::Job* job, QWidget* parent);
-        ~ScanExtender() override;
+/**
+    Extender widget which displays the results of a data scan
+*/
+class ScanExtender : public JobProgressWidget, public Ui_ScanExtender
+{
+    Q_OBJECT
+public:
+    ScanExtender(bt::Job* job, QWidget* parent);
+    ~ScanExtender() override;
 
-        void description(const QString& title, const QPair< QString, QString >& field1, const QPair< QString, QString >& field2) override;
-        void infoMessage(const QString& plain, const QString& rich) override;
-        void warning(const QString& plain, const QString& rich) override;
-        void percent(long unsigned int percent) override;
-        void speed(long unsigned int value) override;
-        void processedAmount(KJob::Unit unit, qulonglong amount) override;
-        void totalAmount(KJob::Unit unit, qulonglong amount) override;
-        bool similar(Extender* ext) const override;
+    void description(const QString& title, const QPair< QString, QString >& field1, const QPair< QString, QString >& field2) override;
+    void infoMessage(const QString& plain, const QString& rich) override;
+    void warning(const QString& plain, const QString& rich) override;
+    void percent(long unsigned int percent) override;
+    void speed(long unsigned int value) override;
+    void processedAmount(KJob::Unit unit, qulonglong amount) override;
+    void totalAmount(KJob::Unit unit, qulonglong amount) override;
+    bool similar(Extender* ext) const override;
 
-    private slots:
-        void cancelPressed();
-        void finished(KJob* j);
-        void closeRequested();
-    };
+private Q_SLOTS:
+    void cancelPressed();
+    void finished(KJob* j);
+    void closeRequested();
+};
 }
 
 #endif // KT_SCANEXTENDER_H
