@@ -18,6 +18,9 @@
  ***************************************************************************/
 
 #include "fadingitem.h"
+
+#include <algorithm>
+
 #include <QPropertyAnimation>
 #include <QPainter>
 #include <QStyleOptionGraphicsItem>
@@ -38,8 +41,7 @@ void FadingItem::updatePixmap()
     mParent.fill(Qt::transparent);
     QPainter painter(&mParent);
     parentItem()->paint(&painter, &option, 0);
-    foreach (QGraphicsItem* item, parentItem()->childItems())
-    {
+    foreach (QGraphicsItem* item, parentItem()->childItems()) {
         painter.save();
         painter.translate(item->pos());
         item->paint(&painter, &option, 0);
@@ -60,7 +62,7 @@ void FadingItem::paint(QPainter* painter, const QStyleOptionGraphicsItem* option
     QPainter tempPainter(&temp);
     QColor color = Qt::black;
 
-    color.setAlphaF(qMin(mOpacity, qreal(0.99)));
+    color.setAlphaF(std::min(mOpacity, qreal(0.99)));
     tempPainter.setCompositionMode(QPainter::CompositionMode_DestinationIn);
     tempPainter.fillRect(mParent.rect(), color);
     painter->drawPixmap(QPoint(0, 0), temp);
@@ -79,8 +81,7 @@ void FadingItem::setOpacityValue(qreal opacityValue)
 
 void FadingItem::animationFinished()
 {
-    if (mShowing)
-    {
+    if (mShowing) {
         parentItem()->show();
     }
 
@@ -90,8 +91,7 @@ void FadingItem::animationFinished()
 void FadingItem::showItem()
 {
     QPropertyAnimation* animation = mAnimation.data();
-    if (!animation)
-    {
+    if (!animation) {
         animation = new QPropertyAnimation(this, "opacityValue");
         animation->setDuration(100);
         animation->setEasingCurve(QEasingCurve::InQuad);
@@ -99,9 +99,7 @@ void FadingItem::showItem()
         animation->setEndValue(1.0);
         mAnimation = animation;
         connect(animation, &QPropertyAnimation::finished, this, &FadingItem::animationFinished);
-    }
-    else if (animation->state() == QAbstractAnimation::Running)
-    {
+    } else if (animation->state() == QAbstractAnimation::Running) {
         animation->pause();
     }
 
@@ -117,12 +115,9 @@ void FadingItem::showItem()
 void FadingItem::hideItem()
 {
     QPropertyAnimation* animation = mAnimation.data();
-    if (!animation)
-    {
+    if (!animation) {
         return;
-    }
-    else if (animation->state() == QAbstractAnimation::Running)
-    {
+    } else if (animation->state() == QAbstractAnimation::Running) {
         animation->pause();
     }
 
