@@ -44,58 +44,58 @@
 namespace kt
 {
 
-    /** \brief Connections tab
-    \author Krzysztof Kundzicz <athantor@gmail.com>
+/** \brief Connections tab
+\author Krzysztof Kundzicz <athantor@gmail.com>
+*/
+
+class ConnsTabPage : public PluginPage
+{
+    Q_OBJECT
+
+private:
+    ///Tab's UI
+    Ui::ConnsWgt* pmConnsUi;
+
+    ///Connections chart widget
+    ChartDrawer* pmConnsChtWgt;
+    ///DHT chart widget
+    ChartDrawer* pmDhtChtWgt;
+
+    /** \brief Leechers in swarms dataset UUID
+
+    Used for identification whether this dataset is already shown on the chart and if it needs to be removed or added on settings chage
     */
+    const QUuid pmLhrSwnUuid;
+    /** \brief Seeds in swarms dataset UUID
 
-    class ConnsTabPage : public PluginPage
-    {
-        Q_OBJECT
+    Used for identification whether this dataset is already shown on the chart and if it needs to be removed or added on settings chage
+    */
+    const QUuid pmSesSwnUuid;
 
-    private:
-        ///Tab's UI
-        Ui::ConnsWgt* pmConnsUi;
+    /** \brief Gathers data about connections
+    \param  pPlug kt::Plugin interface
+    */
+    void GatherConnStats(Plugin* pPlug);
+    /** \brief Gathers data about DHT
+    */
+    void GatherDhtStats();
 
-        ///Connections chart widget
-        ChartDrawer* pmConnsChtWgt;
-        ///DHT chart widget
-        ChartDrawer* pmDhtChtWgt;
-
-        /** \brief Leechers in swarms dataset UUID
-
-        Used for identification whether this dataset is already shown on the chart and if it needs to be removed or added on settings chage
-        */
-        const QUuid pmLhrSwnUuid;
-        /** \brief Seeds in swarms dataset UUID
-
-        Used for identification whether this dataset is already shown on the chart and if it needs to be removed or added on settings chage
-        */
-        const QUuid pmSesSwnUuid;
-
-        /** \brief Gathers data about connections
-        \param  pPlug kt::Plugin interface
-        */
-        void GatherConnStats(Plugin* pPlug);
-        /** \brief Gathers data about DHT
-        */
-        void GatherDhtStats();
-
-        void setupUi() override;
-    public:
-        /** \brief Constructor
-        \param  p Parent
-        */
-        ConnsTabPage(QWidget* p);
-        ///Destructor
-        ~ConnsTabPage() override;
+    void setupUi() override;
+public:
+    /** \brief Constructor
+    \param  p Parent
+    */
+    ConnsTabPage(QWidget* p);
+    ///Destructor
+    ~ConnsTabPage() override;
 
 
-    public slots:
-        void applySettings() override;
-        void updateAllCharts() override;
-        void gatherData(Plugin*) override;
-        void resetAvg(ChartDrawer*) override;
-    };
+public Q_SLOTS:
+    void applySettings() override;
+    void updateAllCharts() override;
+    void gatherData(Plugin*) override;
+    void resetAvg(ChartDrawer*) override;
+};
 
 } // ns end
 
